import React, { useEffect, useRef } from "react";
import { NavigationContainer } from "@react-navigation/native";
import {
  createStackNavigator,
  TransitionPresets,
} from "@react-navigation/stack";
import { createBottomTabNavigator } from "@react-navigation/bottom-tabs";
import { AntDesign, Ionicons } from "@expo/vector-icons";
import { Platform, UIManager } from "react-native";
import { UpdateAsync } from "./UpdateAsync.js";
import Apps from "./Apps";
import tndView from "./ndView";
import TrainBase from "./trainbaseview";
import HowTo from "./howto";
import menu from "./menu";
import News from "./components/news.js";
import Setting from "./components/settings.js";
import TrainMenu from "./components/trainMenu.js";
import FavoriteList from "./components/FavoriteList.js";
const Stack = createStackNavigator();
const Tab = createBottomTabNavigator();
if (Platform.OS === "android") {
  if (UIManager.setLayoutAnimationEnabledExperimental) {
    UIManager.setLayoutAnimationEnabledExperimental(true);
  }
}
export default function App() {
  useEffect(() => {
    UpdateAsync();
  }, []);

  return (
    <NavigationContainer name="Root" style={{ flex: 1 }}>
      <Tab.Navigator>
        <Tab.Screen
          name="login"
          component={top}
          options={{
            tabBarLabel: "位置情報",
            headerTransparent: true,
            gestureEnabled: true,
            tabBarIcon: () => <AntDesign name="barchart" size={32} />,
          }}
        />
        <Tab.Screen
          name="menuPage"
          component={menuPage}
          options={{
            tabBarLabel: "リンク",
            headerTransparent: true,
            gestureEnabled: true,
            tabBarIcon: () => <Ionicons name="ios-radio" size={32} />,
          }}
        />
        <Tab.Screen
          name="home"
          component={tndView}
          options={{
            tabBarLabel: "運行情報",
            headerTransparent: true,
            gestureEnabled: true,
            tabBarIcon: () => <Ionicons name="md-train" size={32} />,
          }}
        />
      </Tab.Navigator>
    </NavigationContainer>
  );
}
const top = ({ navigation }) => {
  useEffect(() => {
    const unsubscribe = navigation.addListener("tabLongPress", (e) => {
      alert("longPress!");
      navigation.navigate("favoriteList", { webview, stationData });
    });

    return unsubscribe;
  }, [navigation]);

  const webview = useRef();
  return (
    <Stack.Navigator>
      <Stack.Screen
        name="Apps"
        options={{
          headerShown: false,
          gestureEnabled: true,
          headerTransparent: true,
        }}
      >
        {(props) => <Apps {...props} webview={webview} />}
      </Stack.Screen>
      <Stack.Screen
        name="trainbase"
        options={{
          title: "トレインビジョン",
          gestureEnabled: true,
          ...TransitionPresets.SlideFromRightIOS,
        }}
      >
        {(props) => <TrainBase {...props} webview={webview} />}
      </Stack.Screen>
      <Stack.Screen
        name="howto"
        options={{
          title: "使い方",
          ...optionData,
        }}
      >
        {(props) => <HowTo {...props} />}
      </Stack.Screen>
      <Stack.Screen name="news" options={optionData}>
        {(props) => <News {...props} />}
      </Stack.Screen>
      <Stack.Screen name="trainMenu" options={optionData}>
        {(props) => <TrainMenu {...props} webview={webview} />}
      </Stack.Screen>
      <Stack.Screen
        name="favoriteList"
        options={{ ...optionData, gestureEnabled: false }}
      >
        {(props) => <FavoriteList {...props} webview={webview} />}
      </Stack.Screen>
    </Stack.Navigator>
  );
};
function menuPage() {
  return (
    <Stack.Navigator>
      <Stack.Screen
        name="menu"
        component={menu}
        options={{
          headerShown: false,
          gestureEnabled: true,
          headerTransparent: true,
        }}
      />
      <Stack.Screen name="setting" component={Setting} options={optionData} />
      <Stack.Screen
        name="trainbase"
        component={TrainBase}
        options={{
          ...TransitionPresets.ModalPresentationIOS,
          cardOverlayEnabled: true,
          headerShown: false,
          gestureEnabled: true,
          headerTransparent: true,
          gestureResponseDistance: { vertical: 300 },
        }}
      />
    </Stack.Navigator>
  );
}
const optionData = {
  gestureEnabled: true,
  ...TransitionPresets.ModalPresentationIOS,
  cardOverlayEnabled: true,
  headerTransparent: true,
  headerShown: false,
};
